==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/service/worker/GetAnalyticsResourcesWorker.java <==
package com.samelement.iot_notification.service.worker;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;

import androidx.annotation.NonNull;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.preference.PreferenceManager;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.service.ApiCalls;
import com.samelement.iot_notification.util.EncryptUtil;
import com.samelement.iot_notification.util.FileUtil;

import java.io.File;
import java.io.IOException;

import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class GetAnalyticsResourcesWorker extends Worker {
    public static String KEY = "GET_ANALYTICS_RESOURCES_KEY";
    private Context context;

    public GetAnalyticsResourcesWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
    }

    @NonNull
    @Override
    public Result doWork() {
        SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(context);
        String apiHost = preferences.getString(IntentKey.KEY_API_HOST, "no-host");
        if (apiHost.equals("no-host")) return Result.failure();

        OkHttpClient client = ApiCalls.getInstance(context).client;

        // Create request for remote resource.
        Request request = new Request.Builder()
                .get()
                .header(IntentKey.KEY_AUTH, "Bearer " + EncryptUtil.getInstance(context).decrypt(preferences.getString(IntentKey.KEY_USER_ACCESS_TOKEN, "invalid-token")))
                .url(apiHost + "/api/en/analyticsresources?limit=1000")
                .build();


        try {
            Response response = null;

            String responseBody = "{\"type\":\"error\",\"title\":\"Error\",\"desc\":\"Not found..!\",\"request\":\"analytics\",\"body\":[]}"; // empty list

            try {
                response = client.newCall(request).execute();
                if (response.isSuccessful()) {
                    // Deserialize HTTP response to concrete type.
                    responseBody = response.body().string();
                }

            } catch (IOException e) {
                Intent failIntent = new Intent(IntentKey.WORKER_FAILED);
                LocalBroadcastManager.getInstance(getApplicationContext()).sendBroadcast(failIntent);
                e.printStackTrace();
            }


            String id = getId().toString();
            File path = getApplicationContext().getFilesDir();
            File file = new File(path, id + ".json");
            try {
                FileUtil.writeToFile(file, responseBody, false);
            } catch (IOException e) {
                e.printStackTrace();
            }

            String deviceId = getInputData().getString(GetDevicesWorker.KEY);
            String analyticId = getInputData().getString(GetAnalyticsWorker.KEY);
            String broadcastKey = getInputData().getString(IntentKey.KEY_BROADCAST);

            Intent intent = new Intent(broadcastKey);
            intent.putExtra(GetDevicesWorker.KEY, deviceId);
            intent.putExtra(GetAnalyticsWorker.KEY, analyticId);
            intent.putExtra(GetAnalyticsResourcesWorker.KEY, id);
            LocalBroadcastManager.getInstance(getApplicationContext()).sendBroadcast(intent);

            return Result.success();
        } catch (Exception e) {
            e.printStackTrace();
        }

        return Result.failure();
    }
}

==> 0.5.3.tar.gz: android/src/main/java/com/samelement/iot_notification/service/worker/GetAnalyticsResourcesWorker.java <==
package com.samelement.iot_notification.service.worker;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;

import androidx.annotation.NonNull;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.preference.PreferenceManager;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.service.ApiCalls;
import com.samelement.iot_notification.util.EncryptUtil;
import com.samelement.iot_notification.util.FileUtil;

import java.io.File;
import java.io.IOException;

import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class GetAnalyticsResourcesWorker extends Worker {
    public static String KEY = "GET_ANALYTICS_RESOURCES_KEY";
    private final Context context;

    public GetAnalyticsResourcesWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
    }

    @NonNull
    @Override
    public Result doWork() {
        SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(context);
        String apiHost = preferences.getString(IntentKey.KEY_API_HOST, "no-host");
        if (apiHost.equals("no-host")) return Result.failure();

        OkHttpClient client = ApiCalls.getInstance(context).client;

        // Create request for remote resource.
        Request request = new Request.Builder()
                .get()
                .header(IntentKey.KEY_AUTH, "Bearer " + EncryptUtil.getInstance(context).decrypt(preferences.getString(IntentKey.KEY_USER_ACCESS_TOKEN, "invalid-token")))
                .url(apiHost + "/api/en/analyticsresources?limit=1000")
                .build();


        try {
            String responseBody = "{\"type\":\"error\",\"title\":\"Error\",\"desc\":\"Not found..!\",\"request\":\"analytics\",\"body\":[]}"; // empty list

            try {
                Response response = client.newCall(request).execute();
                if (response.isSuccessful()) {
                    // Deserialize HTTP response to concrete type.
                    responseBody = response.body().string();
                }

            } catch (IOException e) {
                Intent failIntent = new Intent(IntentKey.WORKER_FAILED);
                LocalBroadcastManager.getInstance(getApplicationContext()).sendBroadcast(failIntent);
                e.printStackTrace();
            }


            String id = getId().toString();
            File path = getApplicationContext().getFilesDir();
            File file = new File(path, id + ".json");
            try {
                FileUtil.writeToFile(file, responseBody, false);
            } catch (IOException e) {
                e.printStackTrace();
            }

            String deviceId = getInputData().getString(GetDevicesWorker.KEY);
            String analyticId = getInputData().getString(GetAnalyticsWorker.KEY);
            String broadcastKey = getInputData().getString(IntentKey.KEY_BROADCAST);

            Intent intent = new Intent(broadcastKey);
            intent.putExtra(GetDevicesWorker.KEY, deviceId);
            intent.putExtra(GetAnalyticsWorker.KEY, analyticId);
            intent.putExtra(GetAnalyticsResourcesWorker.KEY, id);
            LocalBroadcastManager.getInstance(getApplicationContext()).sendBroadcast(intent);

            return Result.success();
        } catch (Exception e) {
            e.printStackTrace();
        }

        return Result.failure();
    }
}
